pub struct RoutingProvider { /* private fields */ }Expand description
A provider that acts as a router, delegating to other providers based on the model name.
Model names must be in the format provider/model (e.g., openai/gpt-4).
Implementations
Sourceimpl RoutingProvider
impl RoutingProvider
Sourcepub fn new(registry: ProviderRegistry) -> Self
pub fn new(registry: ProviderRegistry) -> Self
Create a new routing provider with the given registry